@@ -1,9 +1,6 @@
 from io import StringIO
 
-try:
-    import kim_edn
-except:
-    raise Exception('Failed to import `kim_edn` utility module')
+import kim_edn
 
 from tests.test_kim_property import PyTest
 
@@ -244,9 +241,9 @@ class TestPropertyModule:
                           str_obj, 1,
                           "key", "basis-atom-coordinates", "source-value", 3)
 
-        msg = '\nERROR: there is not enough input arguments '
-        msg += 'to use.\n Processing the {"basis-atom-coordinates"}:'
-        msg += '{"source-value"} input arguments failed.\n The second '
+        msg = 'there is not enough input arguments '
+        msg += 'to use.\nProcessing the {"basis-atom-coordinates"}:'
+        msg += '{"source-value"} input arguments failed.\nThe second '
         msg += 'index is missing from the input arguments.'
 
         self.assertRaisesRegex(self.KIMPropertyError, msg,
@@ -259,9 +256,9 @@ class TestPropertyModule:
                           str_obj, 1,
                           "key", "basis-atom-coordinates", "source-value", 3, 3)
 
-        msg = '\nERROR: there is not enough input arguments '
-        msg += 'to use.\n Processing the {"basis-atom-coordinates"}:'
-        msg += '{"source-value"} input arguments failed.\n '
+        msg = 'there is not enough input arguments '
+        msg += 'to use.\nProcessing the {"basis-atom-coordinates"}:'
+        msg += '{"source-value"} input arguments failed.\n'
         msg += 'At least we need one further input.'
 
         self.assertRaisesRegex(self.KIMPropertyError, msg,
@@ -274,8 +271,8 @@ class TestPropertyModule:
                           str_obj, 1,
                           "key", "basis-atom-coordinates", "source-value", 3, 4)
 
-        msg = '\nERROR: this dimension has a fixed length = 3, while, '
-        msg += 'wrong index = 4 is requested.\n Processing the '
+        msg = 'this dimension has a fixed length = 3, while, '
+        msg += 'wrong index = 4 is requested.\nProcessing the '
         msg += '{"basis-atom-coordinates"}:{"source-value"} input arguments,'
         msg += ' wrong index at the second dimension is requested.'
 
@@ -417,6 +414,11 @@ class TestPropertyModule:
 
         self.assertTrue(sio.getvalue() == out_str)
 
+        # Fail to create a file to dump the property
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.kim_property_modify,
+                          str_obj, "output/results.edn")
+
 
 class TestPyTestPropertyModule(TestPropertyModule, PyTest):
     pass
